==> jc-1.4.0.tar.gz: soot/coffi/Double2ndHalfType.h <==
// public class soot.coffi.Double2ndHalfType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f801e5c664424a1 soot_Type
// @dep_class 600123200b7f27b5 soot_coffi_Double2ndHalfType

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_coffi_Double2ndHalfType_H_
#define _JC_soot_coffi_Double2ndHalfType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_coffi_Double2ndHalfType$object;

// Typedefs
typedef struct _jc_soot_coffi_Double2ndHalfType$sub_refs	_jc_soot_coffi_Double2ndHalfType$sub_refs;
typedef struct _jc_soot_coffi_Double2ndHalfType$sub_nonrefs	_jc_soot_coffi_Double2ndHalfType$sub_nonrefs;
typedef struct _jc_soot_coffi_Double2ndHalfType$refs	_jc_soot_coffi_Double2ndHalfType$refs;
typedef struct _jc_soot_coffi_Double2ndHalfType$nonrefs	_jc_soot_coffi_Double2ndHalfType$nonrefs;
typedef struct _jc_soot_coffi_Double2ndHalfType$object	_jc_soot_coffi_Double2ndHalfType$object;

typedef const struct _jc_soot_coffi_Double2ndHalfType$vmethods	_jc_soot_coffi_Double2ndHalfType$vmethods;
typedef const struct _jc_soot_coffi_Double2ndHalfType$vtable	_jc_soot_coffi_Double2ndHalfType$vtable;
typedef const struct _jc_soot_coffi_Double2ndHalfType$vtype	_jc_soot_coffi_Double2ndHalfType$vtype;

// Constructors
extern void _jc_soot_coffi_Double2ndHalfType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern jboolean _jc_soot_coffi_Double2ndHalfType$method$equals$dd57a1aca6ace081(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *, struct _jc_soot_Type$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Double2ndHalfType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Double2ndHalfType$method_info$equals$dd57a1aca6ace081;
extern _jc_method _jc_soot_coffi_Double2ndHalfType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_coffi_Double2ndHalfType$object *_jc_soot_coffi_Double2ndHalfType$method$v$bc6a684d1e6d4c88(_jc_env *);

// Virtual methods structure
struct _jc_soot_coffi_Double2ndHalfType$vmethods {
	jboolean	(*equals$dd57a1aca6ace081)(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *, struct _jc_soot_Type$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *);
};

// Vtable
struct _jc_soot_coffi_Double2ndHalfType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_coffi_Double2ndHalfType$vmethods	soot_coffi_Double2ndHalfType;
};

// Vtype
struct _jc_soot_coffi_Double2ndHalfType$vtype {
	_jc_type			type;
	_jc_soot_coffi_Double2ndHalfType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Double2ndHalfType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Double2ndHalfType$refs {
    _jc_soot_coffi_Double2ndHalfType$sub_refs	soot_coffi_Double2ndHalfType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Double2ndHalfType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Double2ndHalfType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_coffi_Double2ndHalfType$sub_nonrefs	soot_coffi_Double2ndHalfType;
};

// Object instance structure
struct _jc_soot_coffi_Double2ndHalfType$object {
	_jc_soot_coffi_Double2ndHalfType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Double2ndHalfType$vtype	*vtype;
	_jc_soot_coffi_Double2ndHalfType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Double2ndHalfType$vtype _jc_soot_coffi_Double2ndHalfType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Double2ndHalfType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Double2ndHalfType$class_object;

#endif	/* _JC_soot_coffi_Double2ndHalfType_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Double2ndHalfType.h <==
// public class soot.coffi.Double2ndHalfType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f801e5c664424a1 soot_Type
// @dep_class 600123200b7f27b5 soot_coffi_Double2ndHalfType

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_coffi_Double2ndHalfType_H_
#define _JC_soot_coffi_Double2ndHalfType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_coffi_Double2ndHalfType$object;

// Typedefs
typedef struct _jc_soot_coffi_Double2ndHalfType$sub_refs	_jc_soot_coffi_Double2ndHalfType$sub_refs;
typedef struct _jc_soot_coffi_Double2ndHalfType$sub_nonrefs	_jc_soot_coffi_Double2ndHalfType$sub_nonrefs;
typedef struct _jc_soot_coffi_Double2ndHalfType$refs	_jc_soot_coffi_Double2ndHalfType$refs;
typedef struct _jc_soot_coffi_Double2ndHalfType$nonrefs	_jc_soot_coffi_Double2ndHalfType$nonrefs;
typedef struct _jc_soot_coffi_Double2ndHalfType$object	_jc_soot_coffi_Double2ndHalfType$object;

typedef const struct _jc_soot_coffi_Double2ndHalfType$vmethods	_jc_soot_coffi_Double2ndHalfType$vmethods;
typedef const struct _jc_soot_coffi_Double2ndHalfType$vtable	_jc_soot_coffi_Double2ndHalfType$vtable;
typedef const struct _jc_soot_coffi_Double2ndHalfType$vtype	_jc_soot_coffi_Double2ndHalfType$vtype;

// Constructors
extern void _jc_soot_coffi_Double2ndHalfType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_coffi_Double2ndHalfType$method$equals$dd57a1aca6ace081(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Double2ndHalfType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Double2ndHalfType$method_info$equals$dd57a1aca6ace081;
extern _jc_method _jc_soot_coffi_Double2ndHalfType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_coffi_Double2ndHalfType$object *_jc_soot_coffi_Double2ndHalfType$method$v$bc6a684d1e6d4c88(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Double2ndHalfType$vmethods {
	jboolean	(*equals$dd57a1aca6ace081)(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_Double2ndHalfType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Double2ndHalfType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_coffi_Double2ndHalfType$vmethods	soot_coffi_Double2ndHalfType;
};

// Vtype
struct _jc_soot_coffi_Double2ndHalfType$vtype {
	_jc_type			type;
	_jc_soot_coffi_Double2ndHalfType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Double2ndHalfType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Double2ndHalfType$refs {
    _jc_soot_coffi_Double2ndHalfType$sub_refs	soot_coffi_Double2ndHalfType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Double2ndHalfType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Double2ndHalfType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_coffi_Double2ndHalfType$sub_nonrefs	soot_coffi_Double2ndHalfType;
};

// Object instance structure
struct _jc_soot_coffi_Double2ndHalfType$object {
	_jc_soot_coffi_Double2ndHalfType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Double2ndHalfType$vtype	*vtype;
	_jc_soot_coffi_Double2ndHalfType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Double2ndHalfType$vtype _jc_soot_coffi_Double2ndHalfType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Double2ndHalfType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Double2ndHalfType$class_object;

#endif	/* _JC_soot_coffi_Double2ndHalfType_H_ */
